@@ -1,5 +1,5 @@
-from sumo.constants import __version__, CLUSTER_METHODS, LOG_LEVELS, SIMILARITY_METHODS, VAR_TYPES, CLUSTER_METRICS, \
-    PREPARE_DEFAULTS, EVALUATE_DEFAULTS, RUN_DEFAULTS
+from sumo.constants import __version__, CLUSTER_METHODS, LOG_LEVELS, SIMILARITY_METHODS, CLUSTER_METRICS, \
+    PREPARE_DEFAULTS, EVALUATE_DEFAULTS, RUN_DEFAULTS, SUPPORTED_EXT, INTERPRET_DEFAULTS
 from sumo.modes import SUMO_COMMANDS
 import argparse
 
@@ -13,50 +13,52 @@ def add_prepare_command_options(subparsers):
 
     prepare_parser.add_argument('infiles', metavar='infile1,infile2,...',
                                 type=lambda s: [i for i in s.split(',')],
-                                help='comma-delimited list of paths to input .npz or .txt files (all input files ' +
-                                     'should be structured in following way: consecutive samples in columns, ' +
-                                     'consecutive features in rows")')
-
-    prepare_parser.add_argument('vars', metavar='var1(,var2,...)',
-                                type=lambda s: [i for i in s.split(',')],
-                                help="either one variable type for every data matrix in input file(s) or " +
-                                     "comma-delimited list of variable types {}".format(VAR_TYPES))
+                                help='comma-delimited list of paths to input files, containing standardized feature' +
+                                     ' matrices, with samples in columns and features in rows' +
+                                     ' (supported types of files: {})'.format(SUPPORTED_EXT))
 
     prepare_parser.add_argument('outfile', metavar='outfile.npz',
                                 type=str, help='path to output .npz file')
 
-    prepare_parser.add_argument('-method', action='store', choices=SIMILARITY_METHODS,
-                                type=str, required=False, default=PREPARE_DEFAULTS["method"],
-                                help='method of sample-sample similarity calculation (default of "%(default)s")')
+    method_str = 'either one method of sample-sample similarity calculation, or comma-separated list of methods ' + \
+                 'for every layer (available methods: {}, default of {})'.format(SIMILARITY_METHODS,
+                                                                                 PREPARE_DEFAULTS["method"][0])
+
+    prepare_parser.add_argument('-method', action='store', type=lambda s: [i for i in s.split(',')], required=False,
+                                default=PREPARE_DEFAULTS["method"], help=method_str)
 
     prepare_parser.add_argument('-k', action='store',
                                 type=float, required=False, default=PREPARE_DEFAULTS["k"],
                                 help='fraction of nearest neighbours to use for sample similarity calculation using ' +
-                                     'RBF method (default of %(default)s)')
+                                     'Euclidean distance similarity (default of %(default)s)')
 
     prepare_parser.add_argument('-alpha', action='store',
                                 type=float, required=False, default=PREPARE_DEFAULTS["alpha"],
-                                help='hypherparameter of RBF similarity kernel (default of %(default)s)')
+                                help='hypherparameter of RBF similarity kernel, for Euclidean distance similarity ' +
+                                     '(default of %(default)s)')
 
     prepare_parser.add_argument('-missing', action='store',
-                                type=float, required=False, default=PREPARE_DEFAULTS["missing"],
+                                type=lambda s: [float(i) for i in s.split(',')], required=False,
+                                default=PREPARE_DEFAULTS["missing"],
                                 help='acceptable fraction of available values for assessment of distance/similarity' +
-                                     ' between pairs of samples (default of %(default)s)')
+                                     ' between pairs of samples - either one value or comma-delimited list for every' +
+                                     ' layer (default of %(default)s)')
     # TODO: turn this parameter into fraction of missing samples
 
-    prepare_parser.add_argument('-names', action='store',
-                                type=str, required=False, default=PREPARE_DEFAULTS["names"],
-                                help='optional key of array containing custom sample names in every .npz file ' +
-                                     '(if not set ids of samples are used, which can cause problems ' +
-                                     'when layers have missing samples)')
+    prepare_parser.add_argument('-atol', action='store',
+                                type=float, required=False, default=PREPARE_DEFAULTS["atol"],
+                                help='if input files have continuous values, sumo checks if data is standardized ' +
+                                     'feature-wise, meaning all features should have mean close to zero, with ' +
+                                     'standard deviation around one; use this parameter to set tolerance of ' +
+                                     'standardization checks (default of %(default)s)')
 
     prepare_parser.add_argument('-sn', action='store',
                                 type=int, required=False, default=PREPARE_DEFAULTS["sn"],
-                                help='index of row with sample names for .txt input files (default of %(default)s)')
+                                help='index of row with sample names for input files (default of %(default)s)')
 
     prepare_parser.add_argument('-fn', action='store',
                                 type=int, required=False, default=PREPARE_DEFAULTS["fn"],
-                                help='index of column with feature names for .txt input files (default of %(default)s)')
+                                help='index of column with feature names for input files (default of %(default)s)')
 
     prepare_parser.add_argument('-df', action='store',
                                 type=float, required=False, default=PREPARE_DEFAULTS["df"],
@@ -73,7 +75,7 @@ def add_prepare_command_options(subparsers):
                                 help='path to save log file, by default stdout is used')
 
     prepare_parser.add_argument('-log', default=PREPARE_DEFAULTS["log"], choices=LOG_LEVELS,
-                                help="Sets the logging level (default of %(default)s)")
+                                help="sets the logging level (default of %(default)s)")
 
     prepare_parser.add_argument('-plot', action='store',
                                 type=str, required=False, default=PREPARE_DEFAULTS["plot"],
@@ -135,7 +137,7 @@ def add_run_command_options(subparsers):
                                 help='path to save log file (by default printed to stdout)')
 
     cluster_parser.add_argument('-log', default=RUN_DEFAULTS['log'], choices=LOG_LEVELS,
-                                help="Set the logging level (default of %(default)s)")
+                                help="set the logging level (default of %(default)s)")
 
     cluster_parser.add_argument('-h_init', action='store',
                                 type=int, required=False, default=RUN_DEFAULTS['h_init'],
@@ -151,20 +153,14 @@ def add_evaluate_command_options(subparsers):
 
     description = "Evaluate clustering results, given set of labels"
     evaluate_parser = subparsers.add_parser('evaluate', description=description,
-                                            help='evaluate clustering results')
+                                            help='evaluate or compare clustering results')
 
-    evaluate_parser.add_argument('infile', metavar='infile.npz', type=str,
-                                 help="input .npz file containing array indexed as 'clusters', with sample names " +
-                                      "in first column and clustering labels in second column " +
-                                      "(file created by running sumo with mode 'run')")
+    evaluate_parser.add_argument('infile', metavar='infile.tsv', type=str,
+                                 help="input .tsv file containing sample names in 'sample' and clustering labels" +
+                                      " in 'label' column (clusters.tsv file created by running sumo with mode 'run')")
 
-    evaluate_parser.add_argument('labels', metavar='labels', type=str,
-                                 help="either .npy file containing array with sample names in first column and " +
-                                      "labels in second column or .npz file (requires using '-npz' option)")
-
-    evaluate_parser.add_argument('-npz', action='store',
-                                 type=str, required=False, default=EVALUATE_DEFAULTS['npz'],
-                                 help="key of array containing labels in .npz file")
+    evaluate_parser.add_argument('labels_file', metavar='labels', type=str,
+                                 help=".tsv of the same structure as input file")
 
     evaluate_parser.add_argument('-metric', action='store', choices=CLUSTER_METRICS,
                                  type=str, required=False, default=EVALUATE_DEFAULTS['metric'],
@@ -174,6 +170,72 @@ def add_evaluate_command_options(subparsers):
                                  type=str, required=False, default=EVALUATE_DEFAULTS['logfile'],
                                  help='path to save log file (by default printed to stdout)')
 
+    evaluate_parser.add_argument('-log', default=EVALUATE_DEFAULTS["log"], choices=LOG_LEVELS,
+                                 help="sets the logging level (default of %(default)s)")
+
+
+def add_interpret_command_options(subparsers):
+    """ Add subparser for 'interpret' command """
+
+    description = "Find features that support clusters separation"
+    interpret_parser = subparsers.add_parser('interpret', description=description,
+                                             help='interpret clustering results')
+
+    interpret_parser.add_argument('sumo_results', metavar='sumo_results.npz',
+                                  type=str, help='path to sumo_results.npz (created by running program with mode' +
+                                                 ' "run")')
+
+    interpret_parser.add_argument('infiles', metavar='infile1,infile2,...',
+                                  type=lambda s: [i for i in s.split(',')],
+                                  help='comma-delimited list of paths to input files, containing standardized feature' +
+                                       ' matrices, with samples in columns and features in rows' +
+                                       '(supported types of files: {})'.format(SUPPORTED_EXT))
+
+    interpret_parser.add_argument('outfile', metavar="outfile.tsv", type=str,
+                                  help='output file from this analysis, containing matrix (features x clusters), ' +
+                                       'where the value in each cell is the importance of the feature in that cluster')
+
+    interpret_parser.add_argument('-logfile', action='store',
+                                  type=str, required=False, default=INTERPRET_DEFAULTS['logfile'],
+                                  help='path to save log file (by default printed to stdout)')
+
+    interpret_parser.add_argument('-log', default=INTERPRET_DEFAULTS["log"], choices=LOG_LEVELS,
+                                  help="sets the logging level (default of %(default)s)")
+
+    interpret_parser.add_argument('-max_iter', action='store',
+                                  type=int, required=False, default=INTERPRET_DEFAULTS["max_iter"],
+                                  help='maximum number of iterations, while searching through hyperparameter space')
+
+    interpret_parser.add_argument('-n_folds', action='store',
+                                  type=int, required=False, default=INTERPRET_DEFAULTS["n_folds"],
+                                  help='number of folds for model cross validation (default of %(default)s)')
+
+    interpret_parser.add_argument('-t', action='store',
+                                  type=int, required=False, default=INTERPRET_DEFAULTS["t"],
+                                  help='number of threads (default of %(default)s)')
+
+    interpret_parser.add_argument('-seed', action='store',
+                                  type=int, required=False, default=INTERPRET_DEFAULTS["seed"],
+                                  help='random state (default of %(default)s)')
+
+    interpret_parser.add_argument('-sn', action='store',
+                                  type=int, required=False, default=INTERPRET_DEFAULTS["sn"],
+                                  help='index of row with sample names for input files (default of %(default)s)')
+
+    interpret_parser.add_argument('-fn', action='store',
+                                  type=int, required=False, default=INTERPRET_DEFAULTS["fn"],
+                                  help='index of column with feature names for input files (default of %(default)s)')
+
+    interpret_parser.add_argument('-df', action='store',
+                                  type=float, required=False, default=INTERPRET_DEFAULTS["df"],
+                                  help='if percentage of missing values for feature exceeds this value, remove feature ' +
+                                       '(default of %(default)s)')
+
+    interpret_parser.add_argument('-ds', action='store',
+                                  type=float, required=False, default=INTERPRET_DEFAULTS["ds"],
+                                  help='if percentage of missing values for sample (that remains after feature ' +
+                                       'dropping) exceeds this value, remove sample (default of %(default)s)')
+
 
 def parse_args(argv):
     parser = argparse.ArgumentParser(
@@ -183,7 +245,8 @@ def parse_args(argv):
     subparsers = parser.add_subparsers(help="program mode", dest='command')
     map_subparsers = {"prepare": add_prepare_command_options,
                       "run": add_run_command_options,
-                      "evaluate": add_evaluate_command_options}
+                      "evaluate": add_evaluate_command_options,
+                      "interpret": add_interpret_command_options}
     assert all([command in SUMO_COMMANDS for command in map_subparsers.keys()])
 
     for mode in map_subparsers.keys():
